@@ -69,36 +69,68 @@ class ACEye():
         self.all_files(parsed_json)
         parsed_json = json.dumps(self.fault_summary(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
-        parsed_json = json.dumps(self.audit_log(), indent=4, sort_keys=True)
-        self.all_files(parsed_json)
+        # parsed_json = json.dumps(self.audit_log(), indent=4, sort_keys=True)
+        # self.all_files(parsed_json)
         parsed_json = json.dumps(self.ip_addresses(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
-        parsed_json = json.dumps(self.events(), indent=4, sort_keys=True)
-        self.all_files(parsed_json)
+        # parsed_json = json.dumps(self.events(), indent=4, sort_keys=True)
+        # self.all_files(parsed_json)
         parsed_json = json.dumps(self.licenses(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
         parsed_json = json.dumps(self.bgp_rr(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
         parsed_json = json.dumps(self.interface_policies(), indent=4, sort_keys=True)
         self.all_files(parsed_json)
-
+        parsed_json = json.dumps(self.interface_profiles(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.fabric_pods(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.fabric_paths(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.prefix_list(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.prefix_list_detailed(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.users(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)        
+        parsed_json = json.dumps(self.security_domains(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.contract_subjects(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.health(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.fabric_node_ssl_certificate(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.tenant_health(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.fabric_membership(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.cluster_health(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
 
     def make_directories(self):
-        api_list = ['Tenant',
-                    'Application Profiles',
+        api_list = ['Application Profiles',
                     'Attachable Access Entity Profiles',
                     'Audit Log',
                     'BGP Route Reflectors',
                     'Bridge Domains',
+                    'Cluster Health',
                     'Contexts',
                     'Contracts',
+                    'Contract Subjects',
                     'Endpoints',
                     'EPG',
                     'Events',
+                    'Fabric Membership',
                     'Fabric Nodes',
+                    'Fabric Node SSL Certificates',
+                    'Fabric Paths',
+                    'Fabric Pods',
                     'Fault Summary',
                     'Filters',
+                    'Health',
                     'Interface Policies',
+                    'Interface Profiles',
                     'IP Addresses',
                     'License Entitlements',
                     'L2Outs',
@@ -108,12 +140,17 @@ class ACEye():
                     'Leaf Switch Profiles',
                     'Physical Domains',
                     'Physical Interfaces',
+                    'Prefix List',
+                    'Prefix List Detailed',
                     'QOS Classes',
+                    'Security Domains',
                     'Spine Interface Profiles',
                     'Spine Switch Profiles',
                     'Subnets',
                     'Tenant',
+                    'Tenant Health',
                     'Top System',
+                    'Users',
                     'VLAN Pools']
         current_directory = os.getcwd()
         for api in api_list:
@@ -362,6 +399,111 @@ class ACEye():
         response_dict  = response.json()
         return(response_dict)
 
+    def interface_profiles(self):
+        self.url = f"{ self.aci }/api/node/class/infraProfile.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Interface Profiles Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def fabric_pods(self):
+        self.url = f"{ self.aci }/api/node/class/fabricPod.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Fabric Pods Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def fabric_paths(self):
+        self.url = f"{ self.aci }/api/node/class/fabricPath.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Fabric Paths Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def prefix_list(self):
+        self.url = f"{ self.aci }/api/node/mo/uni/tn-PROD.json?query-target=subtree&target-subtree-class=rtctrlSubjP"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Prefix List Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+        
+    def prefix_list_detailed(self):
+        self.url = f"{ self.aci }/api/node/mo/uni/tn-PROD.json?query-target=subtree&target-subtree-class=rtctrlSubjP"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Prefix List Status code { response.status_code } for { self.url }>")
+        prefix_response_dict  = response.json()
+        ip_prefix_list = []
+        for prefix in prefix_response_dict['imdata']:
+            self.url = f"{ self.aci }/api/node/mo/uni/tn-PROD/subj-{ prefix['rtctrlSubjP']['attributes']['name']}.json?query-target=children&target-subtree-class=rtctrlMatchRtDest"
+            response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+            print(f"<Prefix List Detailed Status code { response.status_code } for { self.url }>")
+            response_dict  = response.json()
+            ip_prefix_list.append(response_dict['imdata'])
+        return(ip_prefix_list)
+
+    def users(self):
+        self.url = f"{ self.aci }/api/node/class/aaaUser.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Users Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def security_domains(self):
+        self.url = f"{ self.aci }/api/node/class/aaaDomain.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Security Domains Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def contract_subjects(self):
+        self.url = f"{ self.aci }/api/node/class/vzSubj.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Contract Subjects Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def health(self):
+        self.url = f"{ self.aci }/api/node/mo/topology/health.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Health Status code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def fabric_node_ssl_certificate(self):
+        self.url = f"{ self.aci }/api/node/class/pkiFabricNodeSSLCertificate.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<PKI Fabric Node SSL Certificate code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def tenant_health(self):
+        self.url = f"{ self.aci }/api/node/class/fvTenant.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Tenant Status code { response.status_code } for { self.url }>")
+        tenants  = response.json()
+        tenant_health = []
+        for tenant in tenants['imdata']:
+            self.url = f"{ self.aci }/api/mo/uni/tn-{ tenant['fvTenant']['attributes']['name'] }/health.json"
+            response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+            print(f"<Tenant Health Status code { response.status_code } for { self.url }>")
+            response_dict  = response.json()
+            tenant_health.append(response_dict['imdata'])
+        return(tenant_health)
+
+    def fabric_membership(self):
+        self.url = f"{ self.aci }/api/node/class/topSystem.json?query-target=subtree&target-subtree-class=firmwareCtrlrRunning"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Fabric Membership code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def cluster_health(self):
+        self.url = f"{ self.aci }/api/node/mo/topology/pod-1/node-1/av.json?query-target=children&target-subtree-class=infraWiNode"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Cluster Health code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
     def json_file(self, parsed_json):
         if "Tenant" in self.url:
             with open('Tenant/JSON/Tenants.json', 'w' ) as f:
@@ -392,8 +534,9 @@ class ACEye():
                 f.write(parsed_json)
 
         if "topSystem" in self.url:
-            with open('Top System/JSON/Top System.json', 'w' ) as f:
-                f.write(parsed_json)
+            if "?" not in self.url:
+                with open('Top System/JSON/Top System.json', 'w' ) as f:
+                    f.write(parsed_json)
 
         if "Subnet" in self.url:
             with open('Subnets/JSON/Subnets.json', 'w' ) as f:
@@ -483,6 +626,58 @@ class ACEye():
             with open('Interface Policies/JSON/Interface Policies.json', 'w' ) as f:
                 f.write(parsed_json)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/JSON/Interface Profiles.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/JSON/Fabric Pods.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/JSON/Fabric Paths.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/JSON/Prefix List.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/JSON/Prefix List Detailed.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "aaaUser" in self.url:
+            with open('Users/JSON/Users.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/JSON/Security Domains.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/JSON/Contract Subjects.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "topology/health" in self.url:
+            with open('Health/JSON/Health.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/JSON/Fabric Node SSL Certificates.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/JSON/Tenant Health.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/JSON/Fabric Membership.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/JSON/Cluster Health.json', 'w' ) as f:
+                f.write(parsed_json)
+
     def yaml_file(self, parsed_json):
         clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
         if "Tenant" in self.url:
@@ -514,8 +709,9 @@ class ACEye():
                 f.write(clean_yaml)
 
         if "topSystem" in self.url:
-            with open('Top System/YAML/Top System.yaml', 'w' ) as f:
-                f.write(clean_yaml)
+            if "?" not in self.url:
+                with open('Top System/YAML/Top System.yaml', 'w' ) as f:
+                    f.write(clean_yaml)
 
         if "Subnet" in self.url:
             with open('Subnets/YAML/Subnets.yaml', 'w' ) as f:
@@ -605,6 +801,58 @@ class ACEye():
             with open('Interface Policies/YAML/Interface Policies.yaml', 'w' ) as f:
                 f.write(clean_yaml)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/YAML/Interface Profiles.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/YAML/Fabric Pods.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/YAML/Fabric Paths.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/YAML/Prefix List.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/YAML/Prefix List Detailed.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "aaaUser" in self.url:
+            with open('Users/YAML/Users.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/YAML/Security Domains.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/YAML/Contract Subjects.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "health" in self.url:
+            with open('Health/YAML/Health.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/YAML/Fabric Node SSL Certificates.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/YAML/Tenant Health.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/YAML/Fabric Membership.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/YAML/Cluster Health.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
     def csv_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -640,8 +888,9 @@ class ACEye():
                 f.write(csv_output)
 
         if "topSystem" in self.url:
-            with open('Top System/CSV/Top System.csv', 'w' ) as f:
-                f.write(csv_output)
+            if "?" not in self.url:
+                with open('Top System/CSV/Top System.csv', 'w' ) as f:
+                    f.write(csv_output)
 
         if "Subnet" in self.url:
             with open('Subnets/CSV/Subnets.csv', 'w' ) as f:
@@ -731,6 +980,58 @@ class ACEye():
             with open('Interface Policies/CSV/Interface Policies.csv', 'w' ) as f:
                 f.write(csv_output)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/CSV/Interface Profiles.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/CSV/Fabric Pods.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/CSV/Fabric Paths.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/CSV/Prefix List.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/CSV/Prefix List Detailed.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "aaaUser" in self.url:
+            with open('Users/CSV/Users.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/CSV/Security Domains.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/CSV/Contract Subjects.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "health" in self.url:
+            with open('Health/CSV/Health.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/CSV/Fabric Node SSL Certificates.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/CSV/Tenant Health.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/CSV/Fabric Membership.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/CSV/Cluster Health.csv', 'w' ) as f:
+                f.write(csv_output)
+
     def markdown_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -767,8 +1068,9 @@ class ACEye():
                 f.write(markdown_output)
 
         if "topSystem" in self.url:
-            with open('Top System/Markdown/Top System.md', 'w' ) as f:
-                f.write(markdown_output)
+            if "?" not in self.url:
+                with open('Top System/Markdown/Top System.md', 'w' ) as f:
+                    f.write(markdown_output)
 
         if "Subnet" in self.url:
             with open('Subnets/Markdown/Subnets.md', 'w' ) as f:
@@ -858,6 +1160,58 @@ class ACEye():
             with open('Interface Policies/Markdown/Interface Policies.md', 'w' ) as f:
                 f.write(markdown_output)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/Markdown/Interface Profiles.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/Markdown/Fabric Pods.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/Markdown/Fabric Paths.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/Markdown/Prefix List.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/Markdown/Prefix List Detailed.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "aaaUser" in self.url:
+            with open('Users/Markdown/Users.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/Markdown/Security Domains.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/Markdown/Contract Subjects.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "health" in self.url:
+            with open('Health/Markdown/Health.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/Markdown/Fabric Node SSL Certificates.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/Markdown/Tenant Health.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/Markdown/Fabric Membership.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/Markdown/Cluster Health.md', 'w' ) as f:
+                f.write(markdown_output)
+
     def html_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -894,8 +1248,9 @@ class ACEye():
                 f.write(html_output)
 
         if "topSystem" in self.url:
-            with open('Top System/HTML/Top System.html', 'w' ) as f:
-                f.write(html_output)
+            if "?" not in self.url:
+                with open('Top System/HTML/Top System.html', 'w' ) as f:
+                    f.write(html_output)
 
         if "Subnet" in self.url:
             with open('Subnets/HTML/Subnets.html', 'w' ) as f:
@@ -985,6 +1340,58 @@ class ACEye():
             with open('Interface Policies/HTML/Interface Policies.html', 'w' ) as f:
                 f.write(html_output)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/HTML/Interface Profiles.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/HTML/Fabric Pods.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/HTML/Fabric Paths.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/HTML/Prefix List.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/HTML/Prefix List Detailed.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "aaaUser" in self.url:
+            with open('Users/HTML/Users.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/HTML/Security Domains.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/HTML/Contract Subjects.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "health" in self.url:
+            with open('Health/HTML/Health.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/HTML/Fabric Node SSL Certificates.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/HTML/Tenant Health.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/HTML/Fabric Membership.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/HTML/Cluster Health.html', 'w' ) as f:
+                f.write(html_output)
+
     def mindmap_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1021,8 +1428,9 @@ class ACEye():
                 f.write(mindmap_output)
 
         if "topSystem" in self.url:
-            with open('Top System/Mindmap/Top System.md', 'w' ) as f:
-                f.write(mindmap_output)
+            if "?" not in self.url:
+                with open('Top System/Mindmap/Top System.md', 'w' ) as f:
+                    f.write(mindmap_output)
 
         if "Subnet" in self.url:
             with open('Subnets/Mindmap/Subnets.md', 'w' ) as f:
@@ -1112,6 +1520,58 @@ class ACEye():
             with open('Interface Policies/Mindmap/Interface Policies.md', 'w' ) as f:
                 f.write(mindmap_output)
 
+        if "infraProfile" in self.url:
+            with open('Interface Profiles/Mindmap/Interface Profiles.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "fabricPod" in self.url:
+            with open('Fabric Pods/Mindmap/Fabric Pods.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "fabricPath" in self.url:
+            with open('Fabric Paths/Mindmap/Fabric Paths.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "rtctrlSubjP" in self.url:
+            with open('Prefix List/Mindmap/Prefix List.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "rtctrlMatchRtDest" in self.url:
+            with open('Prefix List Detailed/Mindmap/Prefix List Detailed.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "aaaUser" in self.url:
+            with open('Users/Mindmap/Users.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "aaaDomain" in self.url:
+            with open('Security Domains/Mindmap/Security Domains.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "vzSubj" in self.url:
+            with open('Contract Subjects/Mindmap/Contract Subjects.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "health" in self.url:
+            with open('Health/Mindmap/Health.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "pkiFabricNodeSSLCertificate" in self.url:
+            with open('Fabric Node SSL Certificates/Mindmap/Fabric Node SSL Certificates.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "tn-" and "health" in self.url:
+            with open('Tenant Health/Mindmap/Tenant Health.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "firmwareCtrlrRunning" in self.url:
+            with open('Fabric Membership/Mindmap/Fabric Membership.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "infraWiNode" in self.url:
+            with open('Cluster Health/Mindmap/Cluster Health.md', 'w' ) as f:
+                f.write(mindmap_output)
+
     def all_files(self, parsed_json):
         self.json_file(parsed_json)
         self.yaml_file(parsed_json)
